@@ -1,5 +1,5 @@
 package Test::Spy::Interface;
-$Test::Spy::Interface::VERSION = '0.001';
+$Test::Spy::Interface::VERSION = '0.002';
 use v5.10;
 use strict;
 use warnings;
@@ -9,6 +9,7 @@ use Mooish::AttributeBuilder;
 
 requires qw(
 	call_history
+	_clear_call_history
 );
 
 has field '_call_iterator' => (
@@ -76,6 +77,13 @@ sub was_called
 	return $self->called_times > 0;
 }
 
+sub wasnt_called
+{
+	my ($self) = @_;
+
+	return $self->was_called(0);
+}
+
 sub was_called_once
 {
 	my ($self) = @_;
